@@ -27,12 +27,14 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 __productname__ = "len8"
-__version__ = "0.2.1"
+__version__ = "0.3.0"
 __description__ = "A utility for keeping line lengths within PEP 8 standards."
 __url__ = "https://github.com/parafoxia/len8"
 __docs__ = "https://len8.readthedocs.io/en/latest/"
 __author__ = "Ethan Henderson, Jonxslays"
 __license__ = "BSD-3-Clause"
 __bugtracker__ = "https://github.com/parafoxia/len8/issues"
+__all__ = ["BadLines", "Checker" ,"InvalidPath", "Len8Error"]
 
-from .checker import check
+from .errors import *
+from .models import Checker
